@@ -318,7 +318,7 @@ class SCD30:
         Arguments:
             offset: temperature offset floating-point value in degrees Celsius.
         """
-        offset_ticks = offset * 100
+        offset_ticks = int(offset * 100)
         return self._send_command(0x5403, 0, [offset_ticks])
 
     def soft_reset(self):
